Module color

Module color 

A common helper type to determine color output.

Enums

UseColor

Constants

COLOR_CLI_COLOR_ENV
A Rusty environment variable for command-line tools, if set to 0 color should not be used, if set to 1 color should be used, otherwise it’s up to the tool to decide.
COLOR_NO_COLOR_ENV
A common environment variable for command-line tools, if set to any value color should not be used.